# Fan Charts

Fan charts [Python](https://www.python.org/) implementation.


The term **fan chart** was coined by the [Bank of England](https://www.bankofengland.co.uk/), which has been
using these charts since 1996 in its "Inflation Report" to describe its best prevision of future inflation to the general public. 
Fan charts have been used extensively in finance and monetary policy, for instance to represent forecasts of inflation.

For more details visit [Fan Charts](https://quantgirl.blog/fan-charts/)